@@ -1,18 +1,21 @@
 package App::Midgen::Role::Output::MB;
 
-use constant {NONE => q{},};
-
+use v5.10;
 use Moo::Role;
 
+# turn off experimental warnings
+no if $] > 5.017010, warnings => 'experimental::smartmatch';
+
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
 
-our $VERSION = '0.33_05';
-$VERSION = eval $VERSION;    ## no critic
-
-use English qw( -no_match_vars );    # Avoids reg-ex performance penalty
+our $VERSION = '0.24';
+use English qw( -no_match_vars ); # Avoids reg-ex performance penalty
 local $OUTPUT_AUTOFLUSH = 1;
 
+use Term::ANSIColor qw( :constants colored );
+use Data::Printer { caller_info => 1, colored => 1, };
+use constant { BLANK => q{ }, NONE => q{}, THREE => 3, };
 use File::Spec;
 
 #######
@@ -20,11 +23,13 @@ use File::Spec;
 #######
 sub header_mb {
 	my $self = shift;
-	my $package_name = shift || NONE;
+	my $package_name = shift // NONE;
 
-	if ($package_name ne NONE) {
+	if ( $package_name ne NONE ) {
+		print "\n";
 		$package_name =~ s{::}{-}g;
-		print "\n" . '"dist_name" => "' . $package_name . q{",} . "\n";
+		say '"dist_name" => "' . $package_name . q{",};
+		print "\n";
 	}
 
 	return;
@@ -36,35 +41,23 @@ sub body_mb {
 	my $self         = shift;
 	my $title        = shift;
 	my $required_ref = shift || return;
-
-	return if not %{$required_ref};
-
 	print "\n";
 
 	my $pm_length = 0;
-	foreach my $module_name (sort keys %{$required_ref}) {
-		if (length $module_name > $pm_length) {
+	foreach my $module_name ( sort keys %{$required_ref} ) {
+		if ( length $module_name > $pm_length ) {
 			$pm_length = length $module_name;
 		}
 	}
+	say q{"} . $title . '" => {';
 
-	$title =~ s/^RuntimeRequires/requires/;
-	$title =~ s/^TestRequires/test_requires/;
-
-	print q{"} . lc $title . '" => {' . "\n";
-
-	foreach my $module_name (sort keys %{$required_ref}) {
-
-		next
-			if $title eq 'test_requires'
-			&& $required_ref->{$module_name} =~ m/mcpan/;
+	foreach my $module_name ( sort keys %{$required_ref} ) {
 
 		my $sq_key = "\"$module_name\"";
-		printf "\t %-*s => \"%s\",\n", $pm_length + 2, $sq_key,
-			$required_ref->{$module_name};
+		printf "\t %-*s => \"%s\",\n", $pm_length + 2, $sq_key, $required_ref->{$module_name};
 
 	}
-	print "},\n";
+	say '},';
 
 	return;
 }
@@ -74,15 +67,16 @@ sub body_mb {
 sub footer_mb {
 	my $self = shift;
 
-	if (defined -d File::Spec->catdir($App::Midgen::Working_Dir, 'script')) {
-		print "\n" . '"script_files" => [' . "\n";
+	if ( defined -d File::Spec->catdir( $App::Midgen::Working_Dir, 'script' ) ) {
+		print "\n";
+		say '"script_files" => [';
 		print "\t\"script/...\"\n";
-		print "],\n";
-	}
-	elsif (defined -d File::Spec->catdir($App::Midgen::Working_Dir, 'bin')) {
-		print "\n" . '"script_files" => [' . "\n";
+		say '],';
+	} elsif ( defined -d File::Spec->catdir( $App::Midgen::Working_Dir, 'bin' ) ) {
+		print "\n";
+		say '"script_files" => [';
 		print "\t\"bin/...\"\n";
-		print "],\n";
+		say '],';
 	}
 
 	print "\n";
@@ -98,16 +92,15 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf8
 
 =head1 NAME
 
-App::Midgen::Role::Output::MB - Output Format - Module::Build,
-used by L<App::Midgen>
+App::Midgen::Role::Output::MB - A collection of output orientated methods used by L<App::Midgen>
 
 =head1 VERSION
 
-version: 0.33_05
+version: 0.24
 
 =head1 DESCRIPTION
 
@@ -148,8 +141,7 @@ See L<App::Midgen>
 
 =head1 LICENSE
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+See L<App::Midgen>
 
 =cut
 
